@@ -41,7 +41,7 @@ define([
     var InstanceEditor = function(pageThis, targetId, containerId='vp-wrapper', popup=false) {
         this.pageThis = pageThis;
         this.targetId = targetId;
-        this.uuid = vpCommon.getUUID();
+        this.uuid = 'u' + vpCommon.getUUID();
         this.containerId = containerId;
         this.popup = popup;
 
@@ -77,7 +77,7 @@ define([
 
     InstanceEditor.prototype.init = function() {
         // load css
-        this.pageThis.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "common/instanceEditor.css");
+        vpCommon.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "common/instanceEditor.css");
 
         this.reload();
     }
